@@ -92,7 +92,7 @@ pub fn compile_anchor(messages: Vec<&str>) -> String {
             // Style variants
             "[$regular]" => result.push_str("\x1b[0m"),
             "[$bold]" => result.push_str("\x1b[1m"),
-            "[$low]" | "[$low_intensity]" | "[$lowintensity]" => result.push_str("\x1b[2m"),
+            "[$low]" | "[$low_intensity]" | "[$lowintensity]" | "$[dim]" => result.push_str("\x1b[2m"),
             "[$italic]" => result.push_str("\x1b[3m"),
             "[$underline]" => result.push_str("\x1b[4m"),
             "[$blink]" | "[$blinking]" => result.push_str("\x1b[5m"),
